@@ -2,4 +2,4 @@
 __all__ = ['StarterPkg', 'ConfigParser']
 
 from .starterpkg import *
-from .utils.configparser import *
\ No newline at end of file
+from .utils.configloader import *
\ No newline at end of file
