@@ -1,13 +1,11 @@
 #!/usr/bin/python3 -B
 from .starterpkg import StarterPkg
-from .utils.configparser import ConfigParser
+from .utils.configloader import ConfigParser
 
 def main():
 	configparser = ConfigParser()
 	starterpkg = StarterPkg(configparser)
-	#starterpkg.run()
-	#print(configparser.filepath)
-	print(configparser.env)
+	starterpkg.run()
 
 if __name__ == '__main__':
 	raise SystemExit(main())
\ No newline at end of file
