@@ -7,24 +7,24 @@ from random import sample
 class StarterPkg:
 
 	def __init__(self, configparser):
+		# Load config file:
+		self.configfile = configparser.configfile
 		parser = configparser.parse()
-
 		if parser['status'] == 200:
-			config = parser['data']
+			self.configdata = parser['data']
 		else:
-			config = {'answers': ['Error: Failed to load config file.']}
+			self.configdata = {'config': 'Error: Failed to load config file.'}
 
-		self.answers = config['answers']
-
-	def get_response(self):
-		return sample(self.answers, 1)[0]
+		# Load package data:
+		data = self.get_pkg_data()
+		self.answers = data['answers']
 
 	def get_pkg_data(self):
 		"""
 		Modern way to get package data is with pkgutil.get_data(). See this post:
 		https://stackoverflow.com/questions/6028000/how-to-read-a-static-file-from-inside-a-python-package/58941536#58941536
 		"""
-		pkgdata = pkgutil.get_data(__name__, 'data/default.json')
+		pkgdata = pkgutil.get_data(__name__, 'data/data.json')
 		return json.loads(pkgdata.decode('utf-8'))
 
 	def get_myip(self):
@@ -32,9 +32,18 @@ class StarterPkg:
 		Modern way to get get my ip using requests. See this post:
 		https://stackoverflow.com/questions/22492484/how-do-i-get-the-ip-address-from-a-http-request-using-the-requests-library/22513161#22513161
 		"""
-		resp = requests.get('https://www.google.com', stream=True)
+		resp = requests.get('https://www.wikipedia.org', stream=True)
 		return resp.raw._connection.sock.getsockname()[0]
 
+	def get_config(self):
+		return self.configdata
+
+	def get_config_loc(self):
+		return self.configfile
+
+	def get_answer(self):
+		return sample(self.answers, 1)[0]
+
 	def splashscreen(self):
 		os.system('clear')
 		print('Welcome to the Python Starter Package')
@@ -42,7 +51,7 @@ class StarterPkg:
 	def optionscreen(self):
 		print(' ')
 		print('What would you like to do?')
-		print('(a) Ask me a question (ip) Get my IP (d) Get package data (q) Quit')
+		print('(a) Ask me a question (ip) Get my IP (c) Get config (l) Get config location (q) Quit')
 
 	def option_a(self):
 		os.system('clear')
@@ -52,7 +61,7 @@ class StarterPkg:
 		os.system('clear')
 		print('Question: ' + question)
 		print(' ')
-		print('Answer: ' + self.get_response())
+		print('Answer: ' + self.get_answer())
 		input()
 		os.system('clear')
 
@@ -60,9 +69,13 @@ class StarterPkg:
 		os.system('clear')
 		print('Your IP: ' + str(self.get_myip()))
 
-	def option_d(self):
+	def option_c(self):
 		os.system('clear')
-		print('Package data: ' + str(self.get_pkg_data()))
+		print('Config: ' + str(self.get_config()))
+
+	def option_l(self):
+		os.system('clear')
+		print('Config Location: ' + str(self.get_config_loc()))
 
 	def run(self):
 		os.system('clear')
@@ -72,8 +85,8 @@ class StarterPkg:
 			self.optionscreen()
 			select = input()
 
-			if select not in ['a', 'ip', 'd', 'q']:
-				#'(a) Ask me a question (ip) Get my IP (d) Get package data (q) Quit'
+			if select not in ['a', 'ip', 'c', 'l' 'q']:
+				#'(a) Ask me a question (ip) Get my IP (c) Get config (l) Get config location (q) Quit'
 				os.system('clear'); print('Invalid selection. Try again.')
 
 			if select == 'q':
@@ -86,5 +99,8 @@ class StarterPkg:
 			if select == 'ip':
 				self.option_ip()
 
-			if select == 'd':
-				self.option_d()
\ No newline at end of file
+			if select == 'c':
+				self.option_c()
+
+			if select == 'l':
+				self.option_l()
\ No newline at end of file
